@@ -35,8 +35,19 @@ class ChangedDocument
 	//! Destructor.
         virtual ~ChangedDocument();
 
+        Glib::ustring get_change_description() const;
+        static Glib::ustring get_change_description_for_items(Tapioca::Item first, Tapioca::Item second);
+
         Tapioca::Document first;
         Tapioca::Document second;
+
+        //operators
+        bool operator==(const ChangedDocument &other)
+          {
+            return first == other.first && second == other.second;
+          }
+
+        bool reverted() {return first == second;}
     protected:
 
     private:
