@@ -16,6 +16,7 @@
 //  02110-1301, USA.
 
 #include "changed-gallery.h"
+#include "changed-document.h"
 
 using namespace Tapioca;
 
@@ -33,3 +34,7 @@ ChangedGallery::~ChangedGallery()
 {
 }
 
+Glib::ustring ChangedGallery::get_change_description() const
+{
+  return ChangedDocument::get_change_description_for_items(first, second);
+}
