@@ -35,8 +35,16 @@ class ChangedGallery
 	//! Destructor.
         virtual ~ChangedGallery();
 
+        Glib::ustring get_change_description() const;
+
         Tapioca::Gallery first;
         Tapioca::Gallery second;
+
+        //operators
+        bool operator==(const ChangedGallery &other)
+          {
+            return first == other.first && second == other.second;
+          }
     protected:
 
     private:
