@@ -26,7 +26,7 @@ using namespace Tapioca;
 class ConnectDialog
 {
  public:
-    ConnectDialog(Tapioca::Profile *p);
+    ConnectDialog(Tapioca::Profile *p, bool modify_username = true);
     ~ConnectDialog();
 
     void set_parent_window(Gtk::Window &parent);
@@ -41,10 +41,13 @@ class ConnectDialog
     Gtk::Dialog* dialog;
     Gtk::Entry *username_entry;
     Gtk::Entry *password_entry;
+    Gtk::Button *accept_button;
 
     //callbacks
     void on_username_changed();
     void on_password_changed();
+    //helpers
+    void update_buttons();
 
 };
 
