@@ -33,29 +33,3 @@ Item::Item()
 Item::~Item()
 {
 }
-
-bool Item::has_tag(std::string tag) const
-{
-  return (std::find(tags.begin(), tags.end(), tag) != tags.end());
-}
-
-void Item::add_tag(std::string tag)
-{
-  if (std::find(tags.begin(), tags.end(), tag) == tags.end())
-    tags.push_back(tag);
-}
-
-void Item::update_tag(std::string oldvalue, std::string newvalue)
-{
-  std::list<std::string>::iterator i = 
-    std::find(tags.begin(), tags.end(), oldvalue);
-  if (i != tags.end())
-    (*i) = newvalue;
-}
-
-void Item::remove_tag(std::string tag)
-{
-  if (std::find(tags.begin(), tags.end(), tag) != tags.end())
-    tags.remove(tag);
-}
-
